@@ -7,8 +7,8 @@ from . import models
 
 
 class AchievementForm(forms.ModelForm):
-    name = forms.CharField(label='Been good? <strong>The Sproutz</strong> lorem ipsum dolor sit amet. And then something else too.')
-    target = forms.IntegerField(label='How many stars will you need?', min_value=models.TARGET_MIN, max_value=models.TARGET_MAX)
+    name = forms.CharField(label='Goal name')
+    target = forms.IntegerField(min_value=models.TARGET_MIN, max_value=models.TARGET_MAX)
     next_url = forms.CharField(required=False, max_length=255, widget=forms.HiddenInput)
 
     class Meta:
